@@ -1,6 +1,6 @@
 package Net::Appliance::Session;
 {
-  $Net::Appliance::Session::VERSION = '3.112290';
+  $Net::Appliance::Session::VERSION = '3.112510';
 }
 
 use Moose;
@@ -42,6 +42,7 @@ foreach my $slot (qw/
 foreach my $slot (qw/
     username
     password
+    privileged_password
 /) {
     has $slot => (
         is => 'rw',
@@ -128,7 +129,7 @@ Net::Appliance::Session - Run command-line sessions to network appliances
 
 =head1 VERSION
 
-version 3.112290
+version 3.112510
 
 =head1 IMPORTANT NOTE ABOUT UPGRADING FROM VERSION 2.x
 
@@ -270,6 +271,15 @@ the username a Perl exception will be thrown.
 The password is cached within the module for possible use later on when
 entering "privileged" mode.
 
+=item C<< privileged_password => $secret >> (optional)
+
+In the situation where you've activated "privileged paging", yet your device
+uses a different password for privileged mode than login, you'll need to set
+that other password here.
+
+Otherwise, because the module tries to disable paging, it first goes into
+privileged mode as you instructed, and fails with the wrong (login) password.
+
 =back
 
 =head2 begin_privileged and end_privileged
