@@ -1,6 +1,6 @@
 package Net::Appliance::Session::Engine;
 {
-  $Net::Appliance::Session::Engine::VERSION = '3.112290';
+  $Net::Appliance::Session::Engine::VERSION = '3.112510';
 }
 
 use Moose::Role;
@@ -76,7 +76,11 @@ sub begin_privileged {
 
     # default is to re-use login credentials
     my $username = $options->has_username ? $options->username : $self->get_username;
-    my $password = $options->has_password ? $options->password : $self->get_password;
+
+    # rt.cpan#69139 support passing of privileged_password to the constructor
+    my $password = $options->has_password ? $options->password :
+                   $self->has_privileged_password ? $self->get_privileged_password
+                                                               : $self->get_password;
 
     $self->macro('begin_privileged');
 
